@@ -4,15 +4,15 @@
  */
 
 #include "CoordgenFragmenter.h"
-#include "sketcherMinimizerMolecule.h"
 #include "sketcherMinimizerAtom.h"
 #include "sketcherMinimizerBond.h"
-#include "sketcherMinimizerRing.h"
 #include "sketcherMinimizerFragment.h"
+#include "sketcherMinimizerMolecule.h"
+#include "sketcherMinimizerRing.h"
 
 #include "sketcherMinimizerMaths.h"
-#include <queue>
 #include <algorithm>
+#include <queue>
 using namespace std;
 
 void CoordgenFragmenter::splitIntoFragments(sketcherMinimizerMolecule* molecule)
@@ -21,20 +21,21 @@ void CoordgenFragmenter::splitIntoFragments(sketcherMinimizerMolecule* molecule)
      split input molecule into rigid fragments
      */
     vector<sketcherMinimizerFragment*> fragments;
-    foreach (sketcherMinimizerAtom* atom, molecule->getAtoms()) {
-        atom->setFragment(NULL);
+    for (sketcherMinimizerAtom* atom : molecule->getAtoms()) {
+        atom->setFragment(nullptr);
     }
 
     /* molecule with a single atom and no bonds */
     if (molecule->getAtoms().size() == 1) {
-        sketcherMinimizerFragment* fragment = new sketcherMinimizerFragment();
+        auto* fragment = new sketcherMinimizerFragment();
         sketcherMinimizerAtom* onlyAtom = molecule->getAtoms().at(0);
         fragment->addAtom(onlyAtom);
         fragments.push_back(fragment);
     }
-    foreach (sketcherMinimizerBond* bond, molecule->_bonds) {
-        if (bond->isResidueInteraction())
+    for (sketcherMinimizerBond* bond : molecule->_bonds) {
+        if (bond->isResidueInteraction()) {
             continue;
+        }
         if (bond->isInterFragment()) {
             processInterFragmentBond(bond, fragments);
         } else {
@@ -53,8 +54,9 @@ void CoordgenFragmenter::splitIntoFragments(sketcherMinimizerMolecule* molecule)
 
 void CoordgenFragmenter::addBondInformation(sketcherMinimizerBond* bond)
 {
-    if (bond->isResidueInteraction())
+    if (bond->isResidueInteraction()) {
         return;
+    }
     if (bond->getStartAtom()->getFragment() ==
         bond->getEndAtom()->getFragment()) {
         bond->getStartAtom()->getFragment()->addBond(bond);
@@ -73,13 +75,13 @@ void CoordgenFragmenter::addRingInformation(sketcherMinimizerRing* ring)
 void CoordgenFragmenter::processInterFragmentBond(
     sketcherMinimizerBond* bond, vector<sketcherMinimizerFragment*>& fragments)
 {
-    if (bond->getStartAtom()->getFragment() == NULL) {
-        sketcherMinimizerFragment* fragment = new sketcherMinimizerFragment();
+    if (bond->getStartAtom()->getFragment() == nullptr) {
+        auto* fragment = new sketcherMinimizerFragment();
         fragment->addAtom(bond->getStartAtom());
         fragments.push_back(fragment);
     }
-    if (bond->getEndAtom()->getFragment() == NULL) {
-        sketcherMinimizerFragment* fragment = new sketcherMinimizerFragment();
+    if (bond->getEndAtom()->getFragment() == nullptr) {
+        auto* fragment = new sketcherMinimizerFragment();
         fragment->addAtom(bond->getEndAtom());
         fragments.push_back(fragment);
     }
@@ -88,17 +90,17 @@ void CoordgenFragmenter::processInterFragmentBond(
 void CoordgenFragmenter::processBondInternalToFragment(
     sketcherMinimizerBond* bond, vector<sketcherMinimizerFragment*>& fragments)
 {
-    if (bond->getStartAtom()->getFragment() == NULL &&
-        bond->getEndAtom()->getFragment() == NULL) {
+    if (bond->getStartAtom()->getFragment() == nullptr &&
+        bond->getEndAtom()->getFragment() == nullptr) {
         /* add the two atoms to a new fragment */
-        sketcherMinimizerFragment* fragment = new sketcherMinimizerFragment();
+        auto* fragment = new sketcherMinimizerFragment();
         fragment->addAtom(bond->getStartAtom());
         fragment->addAtom(bond->getEndAtom());
         fragments.push_back(fragment);
-    } else if (bond->getEndAtom()->getFragment() == NULL) {
+    } else if (bond->getEndAtom()->getFragment() == nullptr) {
         /* extend fragment of start atom */
         bond->getStartAtom()->getFragment()->addAtom(bond->getEndAtom());
-    } else if (bond->getStartAtom()->getFragment() == NULL) {
+    } else if (bond->getStartAtom()->getFragment() == nullptr) {
         /* extend fragment of end atom */
         bond->getEndAtom()->getFragment()->addAtom(bond->getStartAtom());
     } else if (bond->getStartAtom()->getFragment() !=
@@ -113,12 +115,12 @@ void CoordgenFragmenter::joinFragments(
     sketcherMinimizerFragment* fragment1, sketcherMinimizerFragment* fragment2,
     vector<sketcherMinimizerFragment*>& fragments)
 {
-    foreach (sketcherMinimizerAtom* atom, fragment2->atoms()) {
+    for (sketcherMinimizerAtom* atom : fragment2->atoms()) {
         fragment1->addAtom(atom);
     }
 
     // remove fragment2 from fragments and free memory
-    std::vector<sketcherMinimizerFragment*>::iterator positionOfFragment2 =
+    auto positionOfFragment2 =
         remove(fragments.begin(), fragments.end(), fragment2);
     fragments.erase(positionOfFragment2, fragments.end());
     delete fragment2;
@@ -181,18 +183,22 @@ bool CoordgenFragmenter::isChain(const sketcherMinimizerFragment* fragment)
 {
     /* can this fragment be part of a zig-zag chain, e.g. exane? */
     vector<sketcherMinimizerAtom*> fragmentAtoms = fragment->getAtoms();
-    if (fragmentAtoms.size() > 3)
+    if (fragmentAtoms.size() > 3) {
         return false;
-    foreach (sketcherMinimizerAtom* atom, fragmentAtoms) {
-        if (atom->getBonds().size() > 3)
+    }
+    for (sketcherMinimizerAtom* atom : fragmentAtoms) {
+        if (atom->getBonds().size() > 3) {
             return false;
-        if (atom->getRings().size())
+        }
+        if (atom->getRings().size()) {
             return false;
+        }
     }
     vector<sketcherMinimizerBond*> fragmentBonds = fragment->getBonds();
-    foreach (sketcherMinimizerBond* bond, fragmentBonds) {
-        if (bond->getBondOrder() > 2)
+    for (sketcherMinimizerBond* bond : fragmentBonds) {
+        if (bond->getBondOrder() > 2) {
             return false;
+        }
     }
     return true;
 }
@@ -203,19 +209,22 @@ bool CoordgenFragmenter::hasPriority(const sketcherMinimizerFragment* fragment1,
     bool checkNoMore = false;
     int checkN = 0;
     while (!checkNoMore) {
-        int leftValue = getValueOfCheck(fragment1, checkN, checkNoMore);
-        int rightValue = getValueOfCheck(fragment2, checkN, checkNoMore);
-        if (leftValue > rightValue)
+        size_t leftValue = getValueOfCheck(fragment1, checkN, checkNoMore);
+        size_t rightValue = getValueOfCheck(fragment2, checkN, checkNoMore);
+        if (leftValue > rightValue) {
             return true;
-        if (leftValue < rightValue)
+        }
+        if (leftValue < rightValue) {
             return false;
+        }
         ++checkN;
     }
     return false;
 }
 
-int CoordgenFragmenter::getValueOfCheck(
-    const sketcherMinimizerFragment* fragment, int checkN, bool& checkNoMore)
+size_t
+CoordgenFragmenter::getValueOfCheck(const sketcherMinimizerFragment* fragment,
+                                    int checkN, bool& checkNoMore)
 {
     switch (checkN) {
     case 0:
@@ -241,7 +250,7 @@ int CoordgenFragmenter::getValueOfCheck(
 }
 
 sketcherMinimizerFragment* CoordgenFragmenter::findMainFragment(
-    vector<sketcherMinimizerFragment*> fragments)
+    const vector<sketcherMinimizerFragment*>& fragments)
 {
     sketcherMinimizerFragment* mainFragment =
         *(min_element(fragments.begin(), fragments.end(), hasPriority));
@@ -249,19 +258,21 @@ sketcherMinimizerFragment* CoordgenFragmenter::findMainFragment(
     return mainFragment;
 }
 
-sketcherMinimizerFragment*
-CoordgenFragmenter::considerChains(vector<sketcherMinimizerFragment*> fragments,
-                                   sketcherMinimizerFragment* mainFragment)
+sketcherMinimizerFragment* CoordgenFragmenter::considerChains(
+    const vector<sketcherMinimizerFragment*>& fragments,
+    sketcherMinimizerFragment* mainFragment)
 {
 
-    foreach (sketcherMinimizerFragment* fragment, fragments) {
-        if (fragment->fixed || fragment->constrained)
+    for (sketcherMinimizerFragment* fragment : fragments) {
+        if (fragment->fixed || fragment->constrained) {
             return mainFragment;
+        }
     }
     vector<sketcherMinimizerFragment*> longestChain =
         findLongestChain(fragments);
-    if (longestChain.size() >= acceptableChainLength(mainFragment))
+    if (longestChain.size() >= acceptableChainLength(mainFragment)) {
         mainFragment = longestChain.at(0);
+    }
     return mainFragment;
 }
 
@@ -284,42 +295,46 @@ unsigned int CoordgenFragmenter::acceptableChainLength(
 }
 
 vector<sketcherMinimizerFragment*> CoordgenFragmenter::findLongestChain(
-    vector<sketcherMinimizerFragment*> fragments)
+    const vector<sketcherMinimizerFragment*>& fragments)
 {
     vector<sketcherMinimizerFragment*> longestChain;
-    foreach (sketcherMinimizerFragment* fragment, fragments) {
-        if (!fragment->isChain)
+    for (sketcherMinimizerFragment* fragment : fragments) {
+        if (!fragment->isChain) {
             continue;
+        }
         int chainN = 0;
-        foreach (sketcherMinimizerBond* b, fragment->_interFragmentBonds) {
+        for (sketcherMinimizerBond* b : fragment->_interFragmentBonds) {
             sketcherMinimizerFragment* childFragment =
                 (b->getStartAtom()->getFragment() != fragment
                      ? b->getStartAtom()->getFragment()
                      : b->getEndAtom()->getFragment());
-            if (childFragment->isChain)
+            if (childFragment->isChain) {
                 ++chainN;
+            }
         }
-        if (chainN > 1)
+        if (chainN > 1) {
             continue; // it's in the middle of a chain
+        }
         queue<sketcherMinimizerFragment*> q;
         map<sketcherMinimizerFragment*, sketcherMinimizerFragment*> parentMap;
         parentMap[fragment] = fragment; // mark first fragment as parent of
                                         // itself so it results visited
         q.push(fragment);
-        sketcherMinimizerFragment* lastFragment = NULL;
+        sketcherMinimizerFragment* lastFragment = nullptr;
         while (q.size()) {
             lastFragment = q.front();
             q.pop();
-            foreach (sketcherMinimizerBond* b,
-                     lastFragment->_interFragmentBonds) {
+            for (sketcherMinimizerBond* b : lastFragment->_interFragmentBonds) {
                 sketcherMinimizerFragment* childFragment =
                     (b->getStartAtom()->getFragment() != lastFragment
                          ? b->getStartAtom()->getFragment()
                          : b->getEndAtom()->getFragment());
-                if (parentMap[childFragment] != NULL)
+                if (parentMap[childFragment] != nullptr) {
                     continue;
-                if (!childFragment->isChain)
+                }
+                if (!childFragment->isChain) {
                     continue;
+                }
                 parentMap[childFragment] = lastFragment;
                 q.push(childFragment);
             }
@@ -333,28 +348,30 @@ vector<sketcherMinimizerFragment*> CoordgenFragmenter::findLongestChain(
             }
             chain.insert(chain.begin(), recursiveFragment);
         }
-        if (chain.size() > longestChain.size())
+        if (chain.size() > longestChain.size()) {
             longestChain = chain;
+        }
     }
     return longestChain;
 }
 
 void CoordgenFragmenter::addParentRelationsToFragments(
     sketcherMinimizerFragment* mainFragment,
-    vector<sketcherMinimizerFragment*> fragments)
+    const vector<sketcherMinimizerFragment*>& fragments)
 {
     queue<sketcherMinimizerFragment*> fragmentsQueue;
     fragmentsQueue.push(mainFragment);
     while (fragmentsQueue.size() > 0) {
         sketcherMinimizerFragment* fragment = fragmentsQueue.front();
         fragmentsQueue.pop();
-        foreach (sketcherMinimizerBond* bond, fragment->_interFragmentBonds) {
+        for (sketcherMinimizerBond* bond : fragment->_interFragmentBonds) {
             sketcherMinimizerFragment* childFragment =
                 (bond->getStartAtom()->getFragment() == fragment
                      ? bond->getEndAtom()->getFragment()
                      : bond->getStartAtom()->getFragment());
-            if (childFragment == fragment->getParent())
+            if (childFragment == fragment->getParent()) {
                 continue;
+            }
             fragment->_children.push_back(childFragment);
             childFragment->setParent(fragment);
             childFragment->_bondToParent = bond;
@@ -362,7 +379,7 @@ void CoordgenFragmenter::addParentRelationsToFragments(
         }
     }
 
-    foreach (sketcherMinimizerFragment* fragment, fragments) {
+    for (sketcherMinimizerFragment* fragment : fragments) {
         /* swap bonds to parent so that startAtom is always the parent's and
          * endAtom always the child's */
         if (fragment->_bondToParent) {
@@ -393,7 +410,7 @@ void CoordgenFragmenter::orderFragments(
         sketcherMinimizerFragment* fragment = q.front();
         q.pop();
         new_fragments.push_back(fragment);
-        foreach (sketcherMinimizerFragment* child, fragment->_children)
+        for (sketcherMinimizerFragment* child : fragment->_children)
             q.push(child);
     }
     assert(fragments.size() == new_fragments.size());
