@@ -17,27 +17,23 @@ class sketcherMinimizerConstraintInteraction
     : public sketcherMinimizerInteraction
 {
   public:
-    sketcherMinimizerConstraintInteraction(sketcherMinimizerAtom* at1,
-                                           sketcherMinimizerPointF position)
+    sketcherMinimizerConstraintInteraction(
+        sketcherMinimizerAtom* at1, const sketcherMinimizerPointF& position)
         : sketcherMinimizerInteraction(at1, at1), origin(position)
     {
         k = CONSTRAINT_SCALE;
-    };
-    virtual ~sketcherMinimizerConstraintInteraction(){};
+    }
+    ~sketcherMinimizerConstraintInteraction() override = default;
 
     /* calculate the energy of the interaction */
     void energy(float& e) override
     {
         e += k * sketcherMinimizerMaths::squaredDistance(atom1->coordinates,
                                                          origin);
-    };
+    }
 
     /* calculate the forces and apply them */
-    void score(float& totalE, bool = false) override
-    {
-        energy(totalE);
-        return;
-    };
+    void score(float& totalE, bool = false) override { energy(totalE); }
 
   private:
     sketcherMinimizerPointF origin;
