@@ -20,14 +20,14 @@ sketcherMinimizerMolecule::sketcherMinimizerMolecule()
 
       hasFixedFragments(false), hasConstrainedFragments(false),
       needToAlignNonRingAtoms(false), needToAlignWholeMolecule(false),
-      isPlaced(false), m_mainFragment(NULL), m_requireMinimization(false){};
+      isPlaced(false), m_mainFragment(nullptr), m_requireMinimization(false){};
 
 sketcherMinimizerMolecule::~sketcherMinimizerMolecule()
 {
     for (auto ring : _rings) {
         delete ring;
     }
-};
+}
 
 sketcherMinimizerAtom* sketcherMinimizerMolecule::addNewAtom()
 {
@@ -49,8 +49,9 @@ sketcherMinimizerMolecule::addNewBond(sketcherMinimizerAtom* at1,
 int sketcherMinimizerMolecule::totalCharge()
 {
     int charge = 0;
-    for (unsigned int i = 0; i < _atoms.size(); i++)
-        charge += _atoms[i]->charge;
+    for (auto& _atom : _atoms) {
+        charge += _atom->charge;
+    }
     return charge;
 }
 
@@ -64,16 +65,19 @@ void sketcherMinimizerMolecule::boundingBox(sketcherMinimizerPointF& min,
     if (_atoms.size()) {
         min = _atoms[0]->coordinates;
         max = _atoms[0]->coordinates;
-        for (unsigned int i = 0; i < _atoms.size(); i++) {
-            sketcherMinimizerAtom* a = _atoms[i];
-            if (a->coordinates.x() < min.x())
+        for (auto a : _atoms) {
+            if (a->coordinates.x() < min.x()) {
                 min.setX(a->coordinates.x());
-            if (a->coordinates.y() < min.y())
+            }
+            if (a->coordinates.y() < min.y()) {
                 min.setY(a->coordinates.y());
-            if (a->coordinates.x() > max.x())
+            }
+            if (a->coordinates.x() > max.x()) {
                 max.setX(a->coordinates.x());
-            if (a->coordinates.y() > max.y())
+            }
+            if (a->coordinates.y() > max.y()) {
                 max.setY(a->coordinates.y());
+            }
         }
     }
 }
@@ -90,11 +94,12 @@ bool sketcherMinimizerMolecule::minimizationIsRequired()
 
 sketcherMinimizerPointF sketcherMinimizerMolecule::center()
 {
-    if (!_atoms.size())
+    if (!_atoms.size()) {
         return sketcherMinimizerPointF(0.f, 0.f);
+    }
     sketcherMinimizerPointF c(.0f, .0f);
-    for (unsigned int i = 0; i < _atoms.size(); i++) {
-        c += _atoms[i]->coordinates;
+    for (auto& _atom : _atoms) {
+        c += _atom->coordinates;
     }
     return c / _atoms.size();
 }
@@ -103,8 +108,7 @@ void sketcherMinimizerMolecule::assignBondsAndNeighbors(
     std::vector<sketcherMinimizerAtom*>& atoms,
     std::vector<sketcherMinimizerBond*>& bonds)
 {
-    for (unsigned int i = 0; i < atoms.size(); i++) {
-        sketcherMinimizerAtom* atom = atoms[i];
+    for (auto atom : atoms) {
         atom->bonds.clear();
         atom->neighbors.clear();
         atom->residueInteractionPartners.clear();
@@ -112,9 +116,8 @@ void sketcherMinimizerMolecule::assignBondsAndNeighbors(
         atom->rings.clear();
     }
 
-    for (unsigned int i = 0; i < bonds.size(); i++) {
+    for (auto bond : bonds) {
 
-        sketcherMinimizerBond* bond = bonds[i];
         bond->rings.clear();
 
         if (!bond->isResidueInteraction()) {
@@ -138,9 +141,10 @@ void sketcherMinimizerMolecule::assignBondsAndNeighbors(
                 bond->endAtom);
         }
     }
-    for (unsigned int i = 0; i < atoms.size(); i++) {
-        if (atoms[i]->_implicitHs == -1)
-            atoms[i]->_implicitHs = atoms[i]->findHsNumber();
+    for (auto& atom : atoms) {
+        if (atom->_implicitHs == -1) {
+            atom->_implicitHs = atom->findHsNumber();
+        }
     }
 }
 
@@ -152,34 +156,35 @@ void sketcherMinimizerMolecule::forceUpdateStruct(
     sketcherMinimizerMolecule::assignBondsAndNeighbors(atoms, bonds);
 
     findRings(bonds, rings);
-    for (unsigned int i = 0; i < bonds.size(); i++) {
-        for (unsigned int j = 0; j < bonds[i]->rings.size(); j++) {
-            sketcherMinimizerRing* ring = bonds[i]->rings[j];
+    for (auto& bond : bonds) {
+        for (unsigned int j = 0; j < bond->rings.size(); j++) {
+            sketcherMinimizerRing* ring = bond->rings[j];
             bool found = false;
-            for (unsigned int k = 0; k < bonds[i]->startAtom->rings.size();
-                 k++) {
-                if (bonds[i]->startAtom->rings[k] == ring) {
+            for (auto& k : bond->startAtom->rings) {
+                if (k == ring) {
                     found = true;
                     break;
                 }
             }
-            if (!found)
-                bonds[i]->startAtom->rings.push_back(ring);
+            if (!found) {
+                bond->startAtom->rings.push_back(ring);
+            }
             found = false;
-            for (unsigned int k = 0; k < bonds[i]->endAtom->rings.size(); k++) {
-                if (bonds[i]->endAtom->rings[k] == ring) {
+            for (auto& k : bond->endAtom->rings) {
+                if (k == ring) {
                     found = true;
                     break;
                 }
             }
-            if (!found)
-                bonds[i]->endAtom->rings.push_back(ring);
+            if (!found) {
+                bond->endAtom->rings.push_back(ring);
+            }
         }
     }
 
-    for (unsigned int i = 0; i < atoms.size(); i++) {
-        for (unsigned int j = 0; j < atoms[i]->rings.size(); j++) {
-            atoms[i]->rings[j]->_atoms.push_back(atoms[i]);
+    for (auto& atom : atoms) {
+        for (unsigned int j = 0; j < atom->rings.size(); j++) {
+            atom->rings[j]->_atoms.push_back(atom);
         }
     }
 }
@@ -188,14 +193,15 @@ void sketcherMinimizerMolecule::findRings(
     std::vector<sketcherMinimizerBond*>& bonds,
     std::vector<sketcherMinimizerRing*>& rings)
 {
-    for (unsigned int i = 0; i < rings.size(); i++)
-        delete rings[i];
+    for (auto& ring : rings) {
+        delete ring;
+    }
     rings.clear();
     for (unsigned int i = 0; i < bonds.size(); i++) {
-        for (unsigned int ii = 0; ii < bonds.size(); ii++) {
-            bonds[ii]->_SSSRVisited = false;
-            bonds[ii]->_SSSRParent = NULL;
-            bonds[ii]->_SSSRParentAtStart = true;
+        for (auto& bond : bonds) {
+            bond->_SSSRVisited = false;
+            bond->_SSSRParent = nullptr;
+            bond->_SSSRParentAtStart = true;
         }
 
         sketcherMinimizerBond* bond = bonds[i];
@@ -209,13 +215,15 @@ void sketcherMinimizerMolecule::findRings(
             q.pop();
 
             sketcherMinimizerAtom* pivotAtom = lastBond->endAtom;
-            if (!lastBond->_SSSRParentAtStart)
+            if (!lastBond->_SSSRParentAtStart) {
                 pivotAtom = lastBond->startAtom;
+            }
             for (unsigned int j = 0; j < pivotAtom->bonds.size(); j++) {
                 sketcherMinimizerBond* nextBond = pivotAtom->bonds[j];
                 // sketcherMinimizerAtom *nextAtom = pivotAtom->neighbors[j];
-                if (nextBond == lastBond)
+                if (nextBond == lastBond) {
                     continue;
+                }
                 if (nextBond->_SSSRVisited) {
                     if (nextBond == bond) {
                         addRing(closeRing(lastBond), rings);
@@ -223,8 +231,9 @@ void sketcherMinimizerMolecule::findRings(
                     }
 
                 } else {
-                    if (nextBond->endAtom == pivotAtom)
+                    if (nextBond->endAtom == pivotAtom) {
                         nextBond->_SSSRParentAtStart = false;
+                    }
                     nextBond->_SSSRParent = lastBond;
                     nextBond->_SSSRVisited = true;
                     q.push(nextBond);
@@ -232,8 +241,7 @@ void sketcherMinimizerMolecule::findRings(
             }
         }
     }
-    for (unsigned int i = 0; i < rings.size(); i++) {
-        sketcherMinimizerRing* ring = rings[i];
+    for (auto ring : rings) {
         for (unsigned int j = 0; j < ring->_bonds.size(); j++) {
             sketcherMinimizerBond* bond = ring->_bonds[j];
             bond->rings.push_back(ring);
@@ -244,7 +252,7 @@ void sketcherMinimizerMolecule::findRings(
 sketcherMinimizerRing*
 sketcherMinimizerMolecule::closeRing(sketcherMinimizerBond* bond)
 {
-    sketcherMinimizerRing* ring = new sketcherMinimizerRing();
+    auto* ring = new sketcherMinimizerRing();
     sketcherMinimizerBond* lastBond = bond;
     while (lastBond) {
         ring->_bonds.push_back(lastBond);
@@ -257,8 +265,8 @@ void sketcherMinimizerMolecule::addRing(
     sketcherMinimizerRing* ring, std::vector<sketcherMinimizerRing*>& rings)
 {
     bool found = false;
-    for (unsigned int i = 0; i < rings.size(); i++) {
-        if (rings[i]->sameAs(ring)) {
+    for (auto& i : rings) {
+        if (i->sameAs(ring)) {
             found = true;
             break;
         }
